﻿using System;
using Sagede.Core.Logging;

namespace LogiSoft.PluginTemplate
{
	public class TraceLog
	{
		private static ILogger _logger;

		private static readonly object LockObject = new object();

		private static ILogger Logger
		{
			get
			{
				lock (LockObject)
				{
					if (_logger is null)
						_logger = LogManager.GetLogger("LogiSoft", "LogiSoft.PluginTemplate");
					return _logger;
				}
			}
		}

		public static void LogVerbose(string message)
		{
			Logger.LogVerbose(message);
		}

		public static void LogVerbose(string message, params object[] args)
		{
			Logger.LogVerbose(message, args);
		}

		public static void LogError(string message)
		{
			Logger.LogError(message);
		}

		public static void LogError(string message, params string[] args)
		{
			Logger.LogError(message, args);
		}

		public static void LogException(Exception ex)
		{
			if (ex is null)
				return;

			Logger.Error(string.Format("{0},{1},{2}", ex.Message, Environment.NewLine, ex.StackTrace));
			if (ex.InnerException is object)
				LogException(ex.InnerException);
		}

		public static void LogTime(string measurement, long start)
		{
			Logger.LogTime(measurement, start);
		}
	}
}
